package com.ruoyi.api.service;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.ruoyi.api.downstream.YzResult;

/**
 * 商品服务
 *
 * @author chl
 */
public interface IProductService {
    /**
     * 推送商品至中台
     * @return
     */
    YzResult pushProduct() throws JsonProcessingException;

    /**
     * 更新商品至中台
     */
    YzResult updateCloudProduct() throws JsonProcessingException;

    /**
     * 更新sku到中台
     */
    YzResult updateCloudSku() throws JsonProcessingException;

    /**
     * 批量上下架商品
     */
    YzResult displayProductByIds() throws JsonProcessingException;

    /**
     * 通过id获取中台的商品详情
     */
    YzResult findProduct() throws JsonProcessingException;

    /**
     * 删除中台系统商品
     */
    YzResult deleteProduct() throws JsonProcessingException;
    /**
     * 获取中台商品数据
     */
    YzResult getProductsList() throws JsonProcessingException;
}
